//
//  MyModel.h
//  ImageCalc
//
//  Created by Cameron Hayne on Tue May 21 2002.
//  Copyright (c) 2002 Hayne of Tintagel. All rights reserved.
//

#import <Foundation/Foundation.h>

@interface MyModel : NSObject
{
    float		parameter;
    int			width, height;
    NSMutableData	*data, *newData;
    int			dataVersion;
    NSLock		*calculationLock;
    NSLock		*displayLock;
    volatile BOOL	shouldContinueUpdating;
}

// Note on threads & locks:
// We need two separate NSLock variables ('calculationLock' and 'displayLock')
// because each of the two threads sometimes reads and writes
// the shared variable 'data'.
// The main thread reads 'data' when doing a redraw
// and writes 'data' when the window is resized.
// The secondary thread reads 'data' while calculating 'newData'
// and overwrites 'data' with 'newData' once the calculation is done.
// We don't allow 'data' to be read while it is being written to
// or written to while it is being read.
// It is quite likely that at any given time, each thread will hold one of the locks.

- (NSSize)size;
- (NSSize)requestSize:(NSSize)aSize;
- (void)startUpdate;
- (void)stopUpdate;
- (void)update:(id)obj;
- (NSData *)data;
- (int)dataVersion;
- (NSLock *)displayLock;
- (float)parameter;
- (void)setParameter:(float)value;

@end
